package com.example.hangman;

import java.util.Random;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.database.Cursor;
import android.graphics.Color;
import android.net.Uri;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.support.v4.app.NavUtils;
import android.view.Gravity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.GridView;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

public class GameActivity extends Activity {

	private String[] words;
	private Random rand;
	private String currWord;
	private LinearLayout wordLayout;
	private TextView[] charViews;
	private GridView letters;
	private LetterAdapter ltrAdapt;
	private AlertDialog helpAlert;

	//body part images
	private ImageView[] bodyParts;
	//number of body parts
	private int numParts=6;
	//current part - will increment when wrong answers are chosen
	private int currPart;
	//number of characters in current word
	private int numChars;
	//number correctly guessed
	private int numCorr;

	private Cursor cursor;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_game);

//		words = getResources().getStringArray(R.array.words);
		cursor = getContacts();
		rand = new Random();
		currWord = "";

		wordLayout = (LinearLayout)findViewById(R.id.word);

		letters = (GridView)findViewById(R.id.letters);

		bodyParts = new ImageView[numParts];
		bodyParts[0] = (ImageView)findViewById(R.id.head);
		bodyParts[1] = (ImageView)findViewById(R.id.body);
		bodyParts[2] = (ImageView)findViewById(R.id.arm1);
		bodyParts[3] = (ImageView)findViewById(R.id.arm2);
		bodyParts[4] = (ImageView)findViewById(R.id.leg1);
		bodyParts[5] = (ImageView)findViewById(R.id.leg2);

		getActionBar().setDisplayHomeAsUpEnabled(true);

		playGame();
	}

	private void playGame() {
		//play a new game
		//String newWord = words[rand.nextInt(words.length)];
		//while(newWord.equals(currWord)) newWord = words[rand.nextInt(words.length)];

		cursor.moveToPosition(rand.nextInt(cursor.getCount()));
		String newWord = cursor.getString(1).toUpperCase();
		while(newWord.equals(currWord)) {
			cursor.moveToPosition(rand.nextInt(cursor.getCount()));
			newWord = cursor.getString(1).toUpperCase();
		}

		currWord = newWord;
		
		charViews = new TextView[currWord.length()];
		wordLayout.removeAllViews();
		for (int c = 0; c < currWord.length(); c++) {
			charViews[c] = new TextView(this);
			charViews[c].setText(""+currWord.charAt(c));
			charViews[c].setLayoutParams(new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT));
			charViews[c].setGravity(Gravity.CENTER);
			charViews[c].setTextColor(Color.WHITE);
			charViews[c].setBackgroundResource(R.drawable.letter_bg);
			//add to layout
			wordLayout.addView(charViews[c]);
		}

		ltrAdapt=new LetterAdapter(this);
		letters.setAdapter(ltrAdapt);

		currPart=0;
		numChars=currWord.length();
		numCorr=0;

		for(int p = 0; p < numParts; p++) {
			bodyParts[p].setVisibility(View.INVISIBLE);
		}
	}

	public void letterPressed(View view) {
		//user has pressed a letter to guess
		String ltr=((TextView)view).getText().toString();
		char letterChar = ltr.charAt(0);
		view.setEnabled(false);
		view.setBackgroundResource(R.drawable.letter_down);

		boolean correct = false;
		for(int k = 0; k < currWord.length(); k++) {
			if(currWord.charAt(k)==letterChar){
				correct = true;
				numCorr++;
				charViews[k].setTextColor(Color.BLACK);
			}
		}

		if (correct) {
			//correct guess
			if (numCorr == numChars-1) {
				// Disable Buttons
				disableBtns();

				// Display Alert Dialog
				AlertDialog.Builder winBuild = new AlertDialog.Builder(this);
				winBuild.setTitle("YAY");
				winBuild.setMessage("You win!\n\nThe answer was:\n\n"+currWord);
				winBuild.setPositiveButton("Play Again",
						new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface dialog, int id) {
						GameActivity.this.playGame();
					}});

				winBuild.setNegativeButton("Exit",
						new DialogInterface.OnClickListener() {
					public void onClick(DialogInterface dialog, int id) {
						GameActivity.this.finish();
					}});

				winBuild.show();
			}
		}else if (currPart < numParts) {
			//some guesses left
			bodyParts[currPart].setVisibility(View.VISIBLE);
			currPart++;
		}else{
			//user has lost
			disableBtns();

			// Display Alert Dialog
			AlertDialog.Builder loseBuild = new AlertDialog.Builder(this);
			loseBuild.setTitle("OOPS");
			loseBuild.setMessage("You lose!\n\nThe answer was:\n\n"+currWord);
			loseBuild.setPositiveButton("Play Again",
					new DialogInterface.OnClickListener() {
				public void onClick(DialogInterface dialog, int id) {
					GameActivity.this.playGame();
				}});

			loseBuild.setNegativeButton("Exit",
					new DialogInterface.OnClickListener() {
				public void onClick(DialogInterface dialog, int id) {
					GameActivity.this.finish();
				}});

			loseBuild.show();
		}


	}

	public void disableBtns() {
		int numLetters = letters.getChildCount();
		for (int l = 0; l < numLetters; l++) {
			letters.getChildAt(l).setEnabled(false);
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case android.R.id.home:
			NavUtils.navigateUpFromSameTask(this);
			return true;
		case R.id.action_help:
			showHelp();
			return true;
		}

		return super.onOptionsItemSelected(item);
	}

	public void showHelp() {
		AlertDialog.Builder helpBuild = new AlertDialog.Builder(this);

		helpBuild.setTitle("Help");
		helpBuild.setMessage("Guess the word by selecting the letters.\n\n"
				+ "You only have 6 wrong selections then it's game over!");
		helpBuild.setPositiveButton("OK",
				new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int id) {
				helpAlert.dismiss();
			}});
		helpAlert = helpBuild.create();

		helpBuild.show();
	}
	
	private Cursor getContacts() {
		    // Run query
		    Uri uri = ContactsContract.Contacts.CONTENT_URI;
		    String[] projection = new String[] { ContactsContract.Contacts._ID,
		        ContactsContract.Contacts.DISPLAY_NAME };
		    String selection = ContactsContract.Contacts.IN_VISIBLE_GROUP + " = '"
		        + ("1") + "'";
		    String[] selectionArgs = null;
		    // note that we sort differently here
		    String sortOrder = ContactsContract.Contacts.DISPLAY_NAME
		        + " COLLATE LOCALIZED ASC";

		    return getContentResolver().query(uri, projection, selection, selectionArgs, sortOrder);
		    
		  }

}
